function[zt,eta] = diff_pp_kpss(x,d,h,opt)
%
%   Applying the Phillips-Perron and KPPP tests
%       to the d-th differenced series, with a mean
%       correction following Shimotsu (2006)
%   
%   input:  x: data (nx1 vector)
%           d: estimate of the memory parameter
%           h: lag length for the PP and KPPP test
%           opt: 1 if you want to detrend the data
%
%__________________________________________________________

weight = (d<=0.5) + (1/2)*(1 + cos(4*pi*d))*(d>0.5)*(d<0.75);

if opt==1
    [n,dum] = size(x);
    z = [ones(n,1) (1:1:n)'];
    pmat = z*((z'*z)\z');
    x = x - pmat*x;     % demean & detrend
end    
    
myuhat = weight*mean(x) + (1-weight)*x(1);
x = x - myuhat;
e = fracdiff(x,d);
ee = cumsum(e);

eta = kpss(e,h,0);
[dum,zt] = pperron(ee,h,1);
