% EXAMPLE.M performs the tests of true versus spurious I(d) models.
%
%	See Shimotsu (2006) "Simple (but Effective) Tests of Long Memory
%	versus Structural Breaks" QED Working paper No. 1101 for details.
%
%   This code requires the codes in elwcode.zip and
%   crittable.m, splitwaldtest.m, diff_pp_kpss.m, pperron.m, kpss.m
%
%
%									Katsumi Shimotsu, March 2007
%_______________________________________________________________

n = 240;           % sample size

d = 0.7;            % the true value of d

u = randn(n,1);     % In this example, we generate an I(d) process with 240 obs.
x = fracdiff(u,-d); % Replace this part with your data.

bset = [2 4];		% note that n/b must be integer

m = 60; 			% note that m/b also must be integer

[wald,avedhat,dhats] = splitwaldtest(x,m,bset,1);	% I use option=1 because d may be larger than 0.5

dhat = felw2st(x,m,3,5);	% 2-step FELW estimate

h = floor(m^0.4);			% lag length for PP and KPSS tests (l in the paper)

[zt,eta] = diff_pp_kpss(x,dhat,h,0);
crit = crittable(dhat,0);  % critical values for the PP and KPSS tests
