% function eta = kpss(x,m,opt)
% KPSS.M computes the KPSS test statistic using
% the Bartlett kernel.
%  
% INPUT	x: data (n*1 vector)
%       m: lag length (scalar)
%       opt: if 0, the data are demeaned.
%            if 1, the data are demeaned & detrended.
%
% asymptotic critical values 
%
% significance
% level          opt=0      opt=1  
%
%   .10:         .347        .119
%   .05:         .463        .146
%   .01          .739        .216
%________________________________________________________________________

function eta = kpss(x,m,opt)
n = size(x,1);

if nargin == 2,
   opt = 0;
end

if opt == 0,
   e = x - sum(x)/n;
else
   z = [ones(n,1) (1:n)'];
   e = x - z*((z'*z)\z')*x;
end

prod = zeros(m,1);

for j = 1:m
   prod(j) = e(j+1:n)'*e(1:n-j);
end

s2 = (e'*e + 2*(1-(1:m)/(m+1))*prod)/n;
S = cumsum(e);
eta = (S'*S)/n^2/s2;
