function[za,zt] = pperron(x,m,opt)
% function[za,zt] = pperron(x,m,opt)
%
%	Phillips-Perron test for unit root
%
%	input: x:data
%		   m:lag length		
%		   opt: 0 if the regressor does not include constant
%               1 if the regressor includes a constant
%               2 if the regressor includes a constant & time trend
%
%	output: Za, Zt statistics
%
%
%							Katsumi Shimotsu, November 2006
%________________________________________________________________

[n,dum] = size(x);

y = x(2:n);
xlag = x(1:n-1);

if opt==0

    x1 = xlag;

elseif opt==1

	x1 = [xlag ones(n-1,1)];
    
elseif opt==2
    
	x1 = [xlag ones(n-1,1) (1:1:n-1)'];

else    
    
disp('error: opt must be {0,1,2}');

end

beta = x1\y;
alpha = beta(1,1);
u = y - x1*beta;

s2 = u'*u/n;
    
prod = zeros(m,1);

for j = 1:m
    prod(j) = u(j+1:n-1)'*u(1:n-1-j);
end

stl = s2 + 2*(1-(1:m)/(m+1))*prod/n;

if opt==0

xx = xlag'*xlag/(n^2);
za = n*(alpha-1) - (1/2)*(stl-s2)/xx;
zt = sqrt(xlag'*xlag)*(alpha-1)/sqrt(stl) - (1/2)*(stl-s2)/sqrt(stl*xx);

elseif opt==1

m = (xlag - mean(xlag))'*(xlag-mean(xlag))/(n^2);
za = n*(alpha-1) - (1/2)*(stl-s2)/m;
zt = n*sqrt(m)*(alpha-1)/sqrt(stl) - (1/2)*(stl-s2)/sqrt(stl*m);
		
else

myy = xlag'*xlag/n/n;
my = sum(xlag)/n/sqrt(n);
mty = xlag'*(1:1:n-1)'/n/n/sqrt(n);

M = (1-n^(-2))*myy - 12*mty*mty + 12*(1+1/n)*mty*my - (4+6/n+2/n/n)*my*my;
za = n*(alpha-1) - (1/2)*(stl-s2)/M;
c3 = inv(x1'*x1); c3 = c3(1,1);
zt = (alpha-1)/sqrt(c3*stl) - (1/2)*(stl-s2)/sqrt(stl*M);

end


