function[w,avedhat,dhats] = splitwaldtest(x,m,bset,opt1)
%function[w,avedhat,dhats] = splitwaldtest(x,m,bset,opt1);
%
% SPLITWALD computes the estimate of d from splitted sample
% and the adjusted Wald statistic Wc.
%
%   input: x (nx1): data
%          m (scalar): bandwidth
%          bset (1xbb): the set of splits; for example, [2 4].
%          opt1: estimation method. If opt1 = 0, the local Whittle
%           estimator is used. If opt1 = 1, the 2-step feasible
%           exact local Whittle estimator of Shimotsu (2006) is used.
%
%  output: w (1xbb): the adjusted Wald statistic corresponding to bset
%          avedhat (1x(bb+1)): the first element is the estimate of d
%           from the full sample. The rest is the average of the estimate
%           of d from subsamples, corresponding to bset.
%          dhats (1x (1 + b(1) + ... + b(bb) ): estimates of d
%
%               Katsumi Shimotsu, November 2006
%
%_____________________________________________________________________

n = length(x);
bb = length(bset);
w = zeros(1,bb);
avedhat = zeros(1,bb+1);
dhats = [];

if opt1==0
    
    dhat0 = fminbnd('whittle',-0.5, 1,[],x,m);

else

    dhat0 = felw2st(x,m,3,5);

end

avedhat(1,1) = dhat0;
dhats(1,1) = [dhats dhat0];

for l=1:bb
    
        b = bset(l);
        dhat = zeros(b,1);
%        x0 = x;
        x = reshape(x,n/b,b);

        for k=1:b
            m1 = m/b;
            
            if opt1==0
                dw = fminbnd('whittle',-0.5, 1,[],x(:,k),m1);
            else
                dw = felw2st(x(:,k),m1,3,5);
            end
            
            dhat(k,1) = dw;
            avedhat(1,l+1) = mean(dhat);

        end

        dhats = [dhats dhat'];
        t = (1:1:m1)';
        myu = log(t) - mean(log(t));
        cm1 = myu'*myu;  % correction factor: setting cm=m1 gives the uncorrected Wald

        diffvec = repmat(dhat0,b,1) - dhat;
        vmat = b*eye(b) - ones(b,b);
        w(l) = 4*m*(cm1/m1)*diffvec'*pinv(vmat)*diffvec;

end

